==> nextcloud-app-mail-0.10.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/en_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Loading accounts" : "Loading accounts",
    "Error while loading the accounts." : "Error whilst loading the accounts.",
    "Can not load this folder." : "Can not load this folder.",
    "Searching for {query}" : "Searching for {query}",
    "Error while deleting message." : "Error whilst deleting message.",
    "Forwarded message" : "Forwarded message",
    "Choose a folder to store the attachment in" : "Choose a folder to store the attachment in",
    "Attachments saved to Files." : "Attachments saved to Files.",
    "Attachment saved to Files." : "Attachment saved to Files.",
    "Error while saving attachments to Files." : "Error whilst saving attachments to Files.",
    "Error while saving attachment to Files." : "Error whilst saving attachment to Files.",
    "Message flag could not be set." : "Message flag could not be set.",
    "Could not move message." : "Could not move message.",
    "Invalid account" : "Invalid account",
    "Invalid folder" : "Invalid folder",
    "Error while creating the account: " : "Error while creating the account: ",
    "Unknown error" : "Unknown error",
    "Error while updating the account: " : "Error while updating the account: ",
    "All inboxes" : "All inboxes",
    "you" : "you",
    "Send message to {email}" : "Send message to {email}",
    "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
    "Could not load your message" : "Could not load your message",
    "Could not load the desired message" : "Could not load the desired message",
    "Could not load the message" : "Could not load the message",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Save",
    "Saved" : "Saved",
    "Show all folders" : "Show all folders",
    "Collapse folders" : "Collapse folders",
    "Error while deleting account." : "Error whilst deleting account.",
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "An error occurred while uploading {fname}" : "An error occurred while uploading {fname}",
    "Reply" : "Reply",
    "Send" : "Send",
    "Sending …" : "Sending…",
    "Message sent!" : "Message sent!",
    "Server error" : "Server error",
    "An unknown error occurred" : "An unknown error occurred",
    "Opening HTML drafts is not supported yet." : "Opening HTML drafts is not supported yet.",
    "No writable calendars found" : "No writable calendars found",
    "Error while importing the calendar event" : "Error whilst importing the calendar event",
    "Error while downloading calendar event" : "Error whilst downloading calendar event",
    "& others" : "& others",
    "Error while loading messages." : "Error whilst loading messages.",
    "Error while refreshing messages." : "Error while refreshing messages.",
    "Setting up your account" : "Setting up your account",
    "Inbox" : "Inbox",
    "Sent" : "Sent",
    "Drafts" : "Drafts",
    "Archive" : "Archive",
    "Trash" : "Trash",
    "Junk" : "Junk",
    "All" : "All",
    "Favorites" : "Favourites",
    "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
    "Updating account failed: " : "Updating account failed: ",
    "Creating account failed: " : "Creating account failed: ",
    "Delete permanently" : "Delete permanently",
    "IMAP web client" : "IMAP web client",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Easy to use email client which connects to your mail server via IMAP and SMTP.",
    "Error loading message" : "Error loading message",
    "Settings" : "Settings",
    "Forwarding to %s" : "Forwarding to %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Click here if you are not automatically redirected within the next few seconds.",
    "Redirect" : "Redirect",
    "The link leads to %s" : "The link leads to %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continue to %s",
    "Delete account" : "Delete account",
    "Try again" : "Try again",
    "New message" : "New message",
    "Account Settings" : "Account Settings",
    "Aliases" : "Aliases",
    "Mail address" : "Mail address",
    "Display Name" : "Display Name",
    "Account" : "Account",
    "Delete" : "Delete",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
    "Compose new message" : "Compose new message",
    "Newer message" : "Newer message",
    "Older message" : "Older message",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle unread",
    "Search" : "Search",
    "Refresh" : "Refresh",
    "Connect your mail account" : "Connect your mail account",
    "Name" : "Name",
    "Mail Address" : "Mail Address",
    "Password" : "Password",
    "Manual configuration" : "Manual configuration",
    "IMAP Host" : "IMAP Host",
    "IMAP security" : "IMAP security",
    "None" : "None",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP User",
    "IMAP Password" : "IMAP Password",
    "SMTP Host" : "SMTP Host",
    "SMTP security" : "SMTP security",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP User",
    "SMTP Password" : "SMTP Password",
    "Connect" : "Connect",
    "from" : "from",
    "to" : "to",
    "cc" : "cc",
    "bcc" : "bcc",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Note that the mail came from a noreply address so your reply will probably not be read.",
    "Subject" : "Subject",
    "Save all to Files" : "Save all to Files",
    "Add mail account" : "Add mail account",
    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
    "No search results for" : "No search results for",
    "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
    "Show images from this sender" : "Show images from this sender",
    "Forward" : "Forward",
    "No messages in this folder" : "No messages in this folder",
    "Upload attachment" : "Upload attachment",
    "Add attachment from Files" : "Add attachment from Files",
    "Import into calendar" : "Import into calendar",
    "Download attachment" : "Download attachment",
    "Save to Files" : "Save to Files"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.15.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/en_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Inbox" : "Inbox",
    "Sent" : "Sent",
    "Drafts" : "Drafts",
    "Archive" : "Archive",
    "Trash" : "Trash",
    "Junk" : "Junk",
    "All" : "All",
    "Favorites" : "Favourites",
    "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
    "Updating account failed: " : "Updating account failed: ",
    "Creating account failed: " : "Creating account failed: ",
    "Delete permanently" : "Delete permanently",
    "IMAP web client" : "IMAP web client",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Easy to use email client which connects to your mail server via IMAP and SMTP.",
    "Name" : "Name",
    "Mail Address" : "Mail Address",
    "Password" : "Password",
    "IMAP Host" : "IMAP Host",
    "None" : "None",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP User",
    "IMAP Password" : "IMAP Password",
    "SMTP Host" : "SMTP Host",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP User",
    "SMTP Password" : "SMTP Password",
    "Connect" : "Connect",
    "Add mail account" : "Add mail account",
    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "from" : "from",
    "to" : "to",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Subject",
    "Sending …" : "Sending…",
    "Message sent!" : "Message sent!",
    "Send" : "Send",
    "Upload attachment" : "Upload attachment",
    "Add attachment from Files" : "Add attachment from Files",
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "No messages in this folder" : "No messages in this folder",
    "Delete" : "Delete",
    "Could not load your message" : "Could not load your message",
    "Import into calendar" : "Import into calendar",
    "Download attachment" : "Download attachment",
    "Save to Files" : "Save to Files",
    "Choose a folder to store the attachment in" : "Choose a folder to store the attachment in",
    "Save all to Files" : "Save all to Files",
    "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
    "New message" : "New message",
    "Settings" : "Settings",
    "Show all folders" : "Show all folders",
    "Collapse folders" : "Collapse folders",
    "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
    "Compose new message" : "Compose new message",
    "Newer message" : "Newer message",
    "Older message" : "Older message",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle unread",
    "Search" : "Search",
    "Refresh" : "Refresh",
    "Connect your mail account" : "Connect your mail account",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "All inboxes" : "All inboxes",
    "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
    "Could not load the desired message" : "Could not load the desired message",
    "Could not load the message" : "Could not load the message",
    "Error loading message" : "Error loading message",
    "Forwarding to %s" : "Forwarding to %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Click here if you are not automatically redirected within the next few seconds.",
    "Redirect" : "Redirect",
    "The link leads to %s" : "The link leads to %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continue to %s"
},
"nplurals=2; plural=(n != 1);");
